@@ -18,11 +18,11 @@ Test::HTML::Lint - Test::More-style wrapper around HTML::Lint
 
 =head1 VERSION
 
-Version 2.24
+Version 2.28
 
 =cut
 
-$VERSION = '2.24';
+$VERSION = '2.28';
 
 my $Tester = Test::Builder->new;
 
@@ -174,14 +174,19 @@ sub html_fragment_ok {
     }
     else {
         $lint->parse( $html );
-        my $nerr = scalar $lint->errors;
+        $lint->eof();
+
+        # Ignore doc-level errors.
+        my @errors = grep { $_->errcode ne 'doc-tag-required' } $lint->errors;
+
+        my $nerr = @errors;
         $ok = !$nerr;
         $Tester->ok( $ok, $name );
         if ( !$ok ) {
             my $msg = 'Errors:';
             $msg .= " $name" if $name;
             $Tester->diag( $msg );
-            $Tester->diag( $_->as_string ) for $lint->errors;
+            $Tester->diag( $_->as_string ) for @errors;
         }
     }
 
@@ -195,7 +200,7 @@ All bugs and requests are now being handled through GitHub.
 
     https://github.com/petdance/html-lint/issues
 
-DO NOT send bug reports to http://rt.cpan.org/ or http://code.google.com/
+DO NOT send bug reports to http://rt.cpan.org/.
 
 
 =head1 TO DO
@@ -217,7 +222,7 @@ this module is taken.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005-2016 Andy Lester.
+Copyright 2005-2018 Andy Lester.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License v2.0.
